import React from 'react';
import { PropsWithMetadata } from '@highlight-ui/utils-commons';
import { IconProps } from './Icon';
export declare type InteractiveIconProps = PropsWithMetadata<{
    /** Specify a name of the icon */
    iconName: IconProps['name'];
    /** Specify the size of the icon */
    iconSize?: IconProps['size'];
    /** Specify a font family for the icon */
    iconType?: IconProps['type'];
    /** Specify a default color of the icon */
    iconColor?: 'icon-default' | 'icon-subdued' | 'inherit';
    /**
     * Disables the InteractiveIcon. Causes the `onClick` prop to be ignored when this prop is set to `true`.
     */
    disabled?: boolean;
    /**
     * Sets a callback for when other keyboard keys are used on the InteractiveIcon. Ignored when `disabled` is set to `true`.
     *
     * `onKeyDown` needs `onClick` props to work.
     *
     */
    onKeyDown?: (e: React.KeyboardEvent<HTMLSpanElement>) => void;
    /**
     * Sets a callback for when the InteractiveIcon is clicked. Ignored when `disabled` is set to `true`.
     *
     * A click event can happen when the InteractiveIcon is clicked with a mouse pointer.
     */
    onClick?: (e: React.MouseEvent<HTMLSpanElement>) => void;
}> & Omit<React.ComponentPropsWithoutRef<'span'>, 'onClick' | 'onKeyDown' | 'aria-disabled' | 'itemRef' | 'itemType' | 'color'>;
export declare type InteractiveIconRef = React.Ref<HTMLSpanElement>;
declare const InteractiveIcon: React.ForwardRefExoticComponent<{
    /** Specify a name of the icon */
    iconName: IconProps['name'];
    /** Specify the size of the icon */
    iconSize?: IconProps['size'];
    /** Specify a font family for the icon */
    iconType?: IconProps['type'];
    /** Specify a default color of the icon */
    iconColor?: "icon-default" | "icon-subdued" | "inherit" | undefined;
    /**
     * Disables the InteractiveIcon. Causes the `onClick` prop to be ignored when this prop is set to `true`.
     */
    disabled?: boolean | undefined;
    /**
     * Sets a callback for when other keyboard keys are used on the InteractiveIcon. Ignored when `disabled` is set to `true`.
     *
     * `onKeyDown` needs `onClick` props to work.
     *
     */
    onKeyDown?: ((e: React.KeyboardEvent<HTMLSpanElement>) => void) | undefined;
    /**
     * Sets a callback for when the InteractiveIcon is clicked. Ignored when `disabled` is set to `true`.
     *
     * A click event can happen when the InteractiveIcon is clicked with a mouse pointer.
     */
    onClick?: ((e: React.MouseEvent<HTMLSpanElement>) => void) | undefined;
} & {
    metadata?: import("@highlight-ui/utils-commons").ComponentMetadata | undefined;
} & Omit<Pick<React.DetailedHTMLProps<React.HTMLAttributes<HTMLSpanElement>, HTMLSpanElement>, "key" | keyof React.HTMLAttributes<HTMLSpanElement>>, "color" | "itemType" | "itemRef" | "aria-disabled" | "onKeyDown" | "onClick"> & React.RefAttributes<HTMLSpanElement>>;
export default InteractiveIcon;
